# frozen_string_literal: true

module VulnerabilityExports
  module Exporters
    class CsvService
      attr_reader :vulnerabilities

      def initialize(vulnerabilities)
        @vulnerabilities = vulnerabilities
      end

      def generate(&block)
        csv_builder.render(&block)
      end

      private

      def csv_builder
        @csv_builder ||= CsvBuilder.new(vulnerabilities, header_to_value_hash)
      end

      def header_to_value_hash
        {
          'Scanner Type' => 'report_type',
          'Scanner Name' => 'finding_scanner_name',
          'Status' => 'state',
          'Vulnerability' => 'title',
          'Details' => 'description',
          'Additional Info' => -> (vulnerability) { vulnerability.finding_metadata&.fetch('message', nil) },
          'Severity' => 'severity',
          'CVE' => -> (vulnerability) { vulnerability.finding_metadata&.fetch('cve', nil) }
        }
      end
    end
  end
end
